##
##  x264.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_api    0.164
%define       V_date   20240301

#   package information
Name:         x264
Summary:      H.264 Codec Library
URL:          http://x264.nl/
Vendor:       Laurent Aimar, Loren Merritt et al.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Video
License:      GPL
Version:      %{V_api}.%{V_date}
Release:      20240301

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/x264/x264-%{V_date}.tar.xz
Source1:      x264.1
Patch0:       x264.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, nasm >= 2.13, make
PreReq:       OpenPKG, openpkg >= 20160101

%description
    x264 is a free C library for encoding H.264 (MPEG-4 AVC) video
    streams.

%track
    prog x264 = {
        version   = %{V_date}
        url       = http://download.openpkg.org/components/versioned/x264/
        regex     = x264-(\d+)\.tar\.xz
    }

%prep
    %setup -q -n x264
    %patch -p0

%build
    %{l_shtool} subst \
        -e 's;/bin/bash;%{l_bash};g' \
        -e 's;git;false;g' \
        version.sh
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    %{l_bash} ./configure \
        --prefix=%{l_prefix} \
        --disable-avs \
        --disable-lavf \
        --disable-ffms \
        --disable-thread \
        --enable-static
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_shtool} mkdir -f -p -m 744 $RPM_BUILD_ROOT%{l_prefix}/man/man1
    %{l_shtool} install -c -m 644 %{SOURCE x264.1} $RPM_BUILD_ROOT%{l_prefix}/man/man1/
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

